API docs for “spamfighter.core.model.command.ModelBaseCommand”

# Class s.c.m.c.ModelBaseCommand(DomainedCommand):

Part of spamfighter.core.model.command View Source View In Hierarchy

Known subclasses: spamfighter.api.model.classify.ModelClassifyCommand, spamfighter.api.model.train.ModelTrainCommand, spamfighter.core.model.test.test_command.FakeModelCommand

Базовый класс команд, упраявляющих моделью.

Instance Variables | model | модель, которой мы управляем (type: `IModel` )
| message | сообщение, на котором мы тренируемся (type: `IMessage` )
| text | извлеченный текст сообщения (type: `unicode` )

Method | init | Дополнительный метод, может переопределяться в потомках для выполнения процедуры

def init(self): (source)
Дополнительный метод, может переопределяться в потомках для выполнения процедуры дополнительной предварительной инициализации.

Находим домен по пути из корневого.